summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorJesse Duffield <jessedduffield@gmail.com>2023-03-24 18:42:11 +1100
committerJesse Duffield <jessedduffield@gmail.com>2023-03-24 18:42:11 +1100
commit8121a0cc74e5c6074d66f90a1c5af43b100d1f26 (patch)
treef92ab7515e7b9cb0cf8bb1bd1224ee724cc88859 /scripts
parent4b67a45a16196a388216a2dee63c971e32a8ff47 (diff)
remove old integration test recording code
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/bump_gocui.sh6
1 files changed, 4 insertions, 2 deletions
diff --git a/scripts/bump_gocui.sh b/scripts/bump_gocui.sh
index 3e0adebae..13a1f575a 100755
--- a/scripts/bump_gocui.sh
+++ b/scripts/bump_gocui.sh
@@ -1,5 +1,7 @@
+#!/bin/sh
+
# Go's proxy servers are not very up-to-date so that's why we use `GOPROXY=direct`
-# We specify the `awesome` branch to avoid the default behaviour of looking for a semver tag.
-GOPROXY=direct go get -u github.com/jesseduffield/gocui@awesome && go mod vendor && go mod tidy
+# We specify the `master` branch to avoid the default behaviour of looking for a semver tag.
+GOPROXY=direct go get -u github.com/jesseduffield/gocui@master && go mod vendor && go mod tidy
# Note to self if you ever want to fork a repo be sure to use this same approach: it's important to use the branch name (e.g. master)